"use client"

import { motion } from "framer-motion"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Utensils, Building, Heart } from "lucide-react"
import Image from "next/image"

export default function Sectors() {
  const sectors = [
    {
      icon: <Utensils className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Restoranlar (AI Garson)",
      description: "Restoran sektöründe yapay zeka, müşteri deneyimini ve işletme verimliliğini yükseltiyor.",
      details: [
        "Siparişleri hızlı ve doğru bir şekilde alma",
        "Mutfakla entegre olarak sipariş durumunu takip etme",
        "Müşterilere kişiselleştirilmiş önerilerde bulunma",
      ],
      image: "/placeholder.svg?height=300&width=400",
    },
    {
      icon: <Building className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Ofisler ve İşletmeler (AI Sekreter)",
      description: "Kurumsal hayatta yapay zeka destekli sanal sekreterler, iş akışınızı düzene sokar.",
      details: [
        "Randevu planlama ve toplantı hatırlatmaları",
        "Gelen çağrı ve e-postalara ön tarama",
        "Basit müşteri e-postalarını otomatik yanıtlama",
      ],
      image: "/placeholder.svg?height=300&width=400",
    },
    {
      icon: <Heart className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Sağlık ve Terapi (AI Asistan/Terapist)",
      description: "Sağlık sektöründe ve özellikle terapi alanında yapay zeka uygulamaları büyük fark yaratıyor.",
      details: [
        "7/24 danışmanlık ve destek",
        "Duygusal durumu analiz edip uygun yanıtlar verme",
        "Gerektiğinde gerçek bir uzmana yönlendirme",
      ],
      image: "/placeholder.svg?height=300&width=400",
    },
  ]

  const containerVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2,
      },
    },
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 },
    },
  }

  return (
    <section className="py-20 relative animated-gradient-bg" id="sectors">
      <div className="container relative z-10">
        <div className="text-center mb-16">
          <h2 className="text-4xl font-bold mb-4 golden-text">Sektörler</h2>
          <p className="text-muted-foreground max-w-2xl mx-auto">
            Yapay zeka teknolojisinin dokunduğu her sektör, operasyonlarında ve hizmet kalitesinde devrim niteliğinde
            iyileşmeler yaşıyor.
          </p>
        </div>

        <motion.div
          className="space-y-16"
          variants={containerVariants}
          initial="hidden"
          whileInView="visible"
          viewport={{ once: true, amount: 0.2 }}
        >
          {sectors.map((sector, index) => (
            <motion.div
              key={index}
              variants={itemVariants}
              className={`flex flex-col ${index % 2 === 1 ? "md:flex-row-reverse" : "md:flex-row"} gap-8 items-center`}
            >
              <div className="md:w-1/2">
                <Card className="glass-card hover:neon-border transition-all duration-300">
                  <CardHeader>
                    <div className="mb-4">{sector.icon}</div>
                    <CardTitle className="text-xl text-white">{sector.title}</CardTitle>
                    <CardDescription className="text-muted-foreground">{sector.description}</CardDescription>
                  </CardHeader>
                  <CardContent>
                    <ul className="space-y-2">
                      {sector.details.map((detail, i) => (
                        <li key={i} className="flex items-start">
                          <span className="text-primary mr-2">•</span>
                          <span className="text-gray-300">{detail}</span>
                        </li>
                      ))}
                    </ul>
                  </CardContent>
                </Card>
              </div>
              <div className="md:w-1/2 relative">
                <div className="rounded-lg overflow-hidden glass-card neon-border">
                  <div className="relative aspect-video">
                    <Image
                      src={sector.image || "/placeholder.svg"}
                      alt={sector.title}
                      fill
                      className="object-cover opacity-60"
                    />
                    <div className="absolute inset-0 bg-gradient-to-r from-background/80 to-transparent"></div>
                  </div>
                </div>
                <div className="absolute -z-10 inset-0 bg-primary/20 blur-3xl opacity-20 rounded-full transform scale-150"></div>
              </div>
            </motion.div>
          ))}
        </motion.div>
      </div>
    </section>
  )
}

